Command class abstract

Mixed-in types
Implementers

Constructors

Command()

Properties

acceptedFlags → List<String>
no setter
alias → List<String>
no setter
args ↔ List<String>
all arguments
getter/setter pairinherited
childrens → List<Command>
childrens command
no setter
codeSample → String?
no setter
commandName → String
no setter
flags ↔ List<String>
all flags
getter/setter pairinherited
fromArgument → String
return parameter from
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
hint for command line
no setter
maxParameters → int
no setter
name → String
return parameter name
no setterinherited
onCommand → String
return parameter on
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withArgument → String
return parameter with
no setterinherited

Methods

containsArg(String flag) → bool
return true if conatains flags
inherited
execute() → Future<void>
execute command
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate() → bool
validate command line arguments

Operators

operator ==(Object other) → bool
The equality operator.
inherited