JSONASTException class

Implemented types

Constructors

JSONASTException(String rawMessage, String? input, String? source, int? line, int? column)

Properties

column → int?
final
hashCode → int
The hash code for this object.
no setterinherited
input → String?
final
line → int?
final
message → String?
no setter
rawMessage → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited