ArrayNode class

Inheritance

Constructors

ArrayNode([String type = 'Array', Location? loc, List<Node>? children])

Properties

children → List<Node>
final
hashCode → int
The hash code for this object.
no setterinherited
loc → Location?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
finalinherited

Methods

copyWith({String? type, Location? loc, List<Node>? children}) → ArrayNode
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(dynamic other) → bool
The equality operator.
override